package com.hw.mes.service;

import java.util.List;
import com.hw.mes.domain.MesBaseRouteProcess;

/**
 * 工艺路线组成信息Service接口
 * 
 * @author Yinq
 * @date 2024-01-25
 */
public interface IMesBaseRouteProcessService 
{
    /**
     * 查询工艺路线组成信息
     * 
     * @param routeProcessId 工艺路线组成信息主键
     * @return 工艺路线组成信息
     */
    public MesBaseRouteProcess selectMesBaseRouteProcessByRouteProcessId(Long routeProcessId);

    /**
     * 查询工艺路线组成信息列表
     * 
     * @param mesBaseRouteProcess 工艺路线组成信息
     * @return 工艺路线组成信息集合
     */
    public List<MesBaseRouteProcess> selectMesBaseRouteProcessList(MesBaseRouteProcess mesBaseRouteProcess);

    /**
     * 新增工艺路线组成信息
     * 
     * @param mesBaseRouteProcess 工艺路线组成信息
     * @return 结果
     */
    public int insertMesBaseRouteProcess(MesBaseRouteProcess mesBaseRouteProcess);

    /**
     * 修改工艺路线组成信息
     * 
     * @param mesBaseRouteProcess 工艺路线组成信息
     * @return 结果
     */
    public int updateMesBaseRouteProcess(MesBaseRouteProcess mesBaseRouteProcess);

    /**
     * 批量删除工艺路线组成信息
     * 
     * @param routeProcessIds 需要删除的工艺路线组成信息主键集合
     * @return 结果
     */
    public int deleteMesBaseRouteProcessByRouteProcessIds(Long[] routeProcessIds);

    /**
     * 删除工艺路线组成信息信息
     * 
     * @param routeProcessId 工艺路线组成信息主键
     * @return 结果
     */
    public int deleteMesBaseRouteProcessByRouteProcessId(Long routeProcessId);
}
